use std::io::stdin;

use crate::blackjack::BlackjackGame;

pub fn play() -> Result<(), Box<dyn std::error::Error>> {
    let mut game = BlackjackGame::new();

    let deal = game.deal();

    println!(
        "Dealer hand: {} ?",
        game.get_dealer_hand().get_card(0).unwrap()
    );
    println!(
        "Player hand: {} ({})",
        game.get_player_hand(),
        game.get_player_hand().get_blackjack_value()
    );

    match deal {
        crate::blackjack::DealResult::DealerBlackJack => {
            println!("Dealer has a blackjack!");
            return Ok(());
        }
        crate::blackjack::DealResult::PlayerBlackJack => {
            println!("Player has a blackjack!");
            return Ok(());
        }
        crate::blackjack::DealResult::Push => {
            println!("Both Player and dealer have a blackjack!");
            return Ok(());
        }
        crate::blackjack::DealResult::Continue => {}
    }

    loop {
        println!("(H)it (S)tand");

        let mut buffer = String::new();
        stdin().read_line(&mut buffer)?;

        let hit = buffer.trim() == "h";

        if hit {
            let hit_result = game.hit();

            println!(
                "Dealer hand: {} ?",
                game.get_dealer_hand().get_card(0).unwrap()
            );
            println!(
                "Player hand: {} ({})",
                game.get_player_hand(),
                game.get_player_hand().get_blackjack_value()
            );

            match hit_result {
                crate::blackjack::HitResult::Bust => {
                    println!("Player busts");
                    return Ok(());
                }
                crate::blackjack::HitResult::Continue => {}
            }
        } else {
            game.stand();

            let dealer_play = game.dealer_play();

            println!(
                "Dealer hand: {} ({})",
                game.get_dealer_hand(),
                game.get_dealer_hand().get_blackjack_value()
            );
            println!(
                "Player hand: {} ({})",
                game.get_player_hand(),
                game.get_player_hand().get_blackjack_value()
            );

            match dealer_play {
                crate::blackjack::DealerPlayResult::Bust => {
                    println!("Dealer bust. Player wins.");
                }
                crate::blackjack::DealerPlayResult::Push => {
                    println!("Player and dealer have same value. Push.");
                }
                crate::blackjack::DealerPlayResult::StandPlayerLose => {
                    println!("Dealer wins");
                }
                crate::blackjack::DealerPlayResult::StandPlayerWin => {
                    println!("Player wins");
                }
            }

            break;
        }
    }

    Ok(())
}
